@@ -42,9 +42,11 @@ class SiameseModel:
     """
     def __init__(self,
                  spectrum_binner: SpectrumBinner,
-                 base_dims: Tuple[int, int, int] = (600, 500, 500),
+                 base_dims: Tuple[int, ...] = (600, 500, 500),
                  embedding_dim: int = 400,
                  dropout_rate: float = 0.5,
+                 l1_reg: float = 1e-6,
+                 l2_reg: float = 1e-6,
                  keras_model: keras.Model = None):
         """
         Construct SiameseModel
@@ -54,12 +56,16 @@ class SiameseModel:
         spectrum_binner
             SpectrumBinner which is used to bin the spectra data for the model training.
         base_dims
-            Size-3 tuple of integers depicting the dimensions of the 1st, 2nd, and 3rd hidden
+            Tuple of integers depicting the dimensions of the desired hidden
             layers of the base model
         embedding_dim
             Dimension of the embedding (i.e. the output of the base model)
         dropout_rate
-            Dropout rate to be used in the base model
+            Dropout rate to be used in the base model.
+        l1_reg
+            L1 regularization rate. Default is 1e-6.
+        l2_reg
+            L2 regularization rate. Default is 1e-6.
         keras_model
             When provided, this keras model will be used to construct the SiameseModel instance.
             Default is None.
@@ -75,7 +81,9 @@ class SiameseModel:
             self.base = self._get_base_model(input_dim=self.input_dim,
                                              dims=base_dims,
                                              embedding_dim=embedding_dim,
-                                             dropout_rate=dropout_rate)
+                                             dropout_rate=dropout_rate,
+                                             l1_reg=l1_reg,
+                                             l2_reg=l2_reg)
             # Create head model
             self.model = self._get_head_model(input_dim=self.input_dim,
                                               base_model=self.base)
@@ -98,22 +106,26 @@ class SiameseModel:
 
     @staticmethod
     def _get_base_model(input_dim: int,
-                        dims: Tuple[int, int, int] = (600, 500, 500),
+                        dims: Tuple[int, ...] = (600, 500, 500),
                         embedding_dim: int = 400,
-                        dropout_rate: float = 0.25):
+                        dropout_rate: float = 0.25,
+                        l1_reg: float = 1e-6,
+                        l2_reg: float = 1e-6):
+        # pylint: disable=too-many-arguments
         model_input = keras.layers.Input(shape=input_dim, name='base_input')
-        embedding = keras.layers.Dense(dims[0], activation='relu', name='dense1',
-                                       kernel_regularizer=keras.regularizers.l1_l2(l1=1e-6, l2=1e-6))(model_input)
-        embedding = keras.layers.BatchNormalization(name='normalization1')(embedding)
-        embedding = keras.layers.Dropout(dropout_rate, name='dropout1')(embedding)
-        embedding = keras.layers.Dense(dims[1], activation='relu', name='dense2')(embedding)
-        embedding = keras.layers.BatchNormalization(name='normalization2')(embedding)
-        embedding = keras.layers.Dropout(dropout_rate, name='dropout2')(embedding)
-        embedding = keras.layers.Dense(dims[2], activation='relu', name='dense3')(embedding)
-        embedding = keras.layers.BatchNormalization(name='normalization3')(embedding)
-        embedding = keras.layers.Dropout(dropout_rate, name='dropout3')(embedding)
-        embedding = keras.layers.Dense(embedding_dim, activation='relu', name='embedding')(
-            embedding)
+        for i, dim in enumerate(dims):
+            if i == 0:
+                model_layer = keras.layers.Dense(dim, activation='relu', name='dense'+str(i+1),
+                                               kernel_regularizer=keras.regularizers.l1_l2(l1=l1_reg, l2=l2_reg))(
+                   model_input)
+            else:
+                model_layer = keras.layers.Dense(dim, activation='relu',
+                                                 name='dense'+str(i+1))(model_layer)
+            model_layer = keras.layers.BatchNormalization(name='normalization'+str(i+1))(model_layer)
+            model_layer = keras.layers.Dropout(dropout_rate, name='dropout'+str(i+1))(model_layer)
+
+        embedding = keras.layers.Dense(embedding_dim, activation='relu',
+                                       name='embedding')(model_layer)
         return keras.Model(model_input, embedding, name='base')
 
     @staticmethod
